# geoproject


[![image](https://img.shields.io/pypi/v/geoproject.svg)](https://pypi.python.org/pypi/geoproject)
[![image](https://img.shields.io/conda/vn/conda-forge/geoproject.svg)](https://anaconda.org/conda-forge/geoproject)


**A python package for interactive mapping and more.**


-   Free software: MIT license
-   Documentation: https://MartinGLUCP.github.io/geoproject
    

## Features

-   TODO
